@@ -51,7 +51,7 @@ def main_concavity():
 		except:
 			pass
 
-	if(default_param["help"] or len(sys.argv)==1):
+	if(default_param["help"] or len(sys.argv)==2 or "help" in sys.argv ):
 		print("""
 			This command-line tool run concavity analysis tools from LSDTopoTools.
 			Description of the algorithms in Mudd et al., 2018 -> https://www.earth-surf-dynam.net/6/505/2018/
@@ -71,7 +71,10 @@ def main_concavity():
 
 	print("Welcome to the command-line tool to constrain your river network concavity. Refer to Mudd et al., 2018 -> https://www.earth-surf-dynam.net/6/505/2018/ for details about these algorithms.")
 	print("Let me first load the raster ...")
-	mydem = LSDDEM(file_name = default_param["file"], path=default_param["path"], already_preprocessed = False, verbose = False)
+	try:
+		mydem = LSDDEM(file_name = default_param["file"], path=default_param["path"], already_preprocessed = False, verbose = False)
+	except:
+		print("Testing data still to build")
 	print("Got it. Now dealing with the depressions ...")
 	mydem.PreProcessing(filling = True, carving = True, minimum_slope_for_filling = 0.0001) # Unecessary if already preprocessed of course.
 	print("Done! Extracting the river network")
@@ -116,7 +119,7 @@ def temp_concavity_FFS_all():
 
 	default_param = AGPD.ingest_param(default_param, sys.argv)
 
-	if(default_param["help"] or len(sys.argv)==1):
+	if(default_param["help"] or len(sys.argv)==1 or "help" in sys.argv):
 		print("""
 			Experimental command-line tools for concavity constraining. Deprecated now.
 			""")
@@ -174,7 +177,7 @@ lsdtt-concFFS-single file=DEM.tif already_preprocessed X=43422 Y=5353497 AT=2500
 
 	prefix = default_param["prefix"]
 
-	if(default_param["help"] or len(sys.argv)==1):
+	if(default_param["help"] or len(sys.argv)==1 or "help" in sys.argv):
 		print("""
 Command-line tool to constrain concavity for a single basin from its XY coordinates using Normalised disorder method.
 Takes several arguments (the values after = are example values to adapt): 
@@ -240,7 +243,7 @@ lsdtt-concFFS-multiple file=DEM.tif already_preprocessed csv=FeatherRiveroutlets
 	default_param = AGPD.ingest_param(default_param, sys.argv)
 	prefix = default_param["prefix"]
 
-	if(default_param["help"] or len(sys.argv)==1):
+	if(default_param["help"] or len(sys.argv)==1 or "help" in sys.argv):
 		print("""
 Command-line tool to constrain concavity for a multiple basin from their XY coordinates using Normalised disorder method.
 Takes several arguments (the values after = are example values to adapt): 
@@ -331,7 +334,7 @@ lsdtt-concFFS-spawn-outlets file=DEM.tif already_preprocessed min_DA=1e7 max_DA=
 
 	choice_of_method = ["min_area", "main_basin","from_range"]
 
-	if(default_param["help"] or len(sys.argv)==1):
+	if(default_param["help"] or len(sys.argv)==1 or "help" in sys.argv):
 		print("""
 Command-line tool to prechoose the basins used for other analysis. Outputs a file with outlet coordinates readable from other command-line tools and a basin perimeter csv readable by GISs to if the basins corresponds to your needs.
 Takes several arguments (the values after = are example values to adapt): 
@@ -419,7 +422,7 @@ def spawn_XY_outlet_subbasins():
 	default_param["prefix"] = "";
 	default_param = AGPD.ingest_param(default_param, sys.argv)
 
-	if(default_param["help"] or len(sys.argv)==1):
+	if(default_param["help"] or len(sys.argv)==1 or "help" in sys.argv):
 		print("""
 Command-line tool to extract basin information about all the subbasins within a main one. Outputs a file with outlet coordinates readable from other command-line tools and a basin perimeter csv readable by GISs to if the basins corresponds to your needs.
 Takes several arguments (the values after = are example values to adapt): 
@@ -535,7 +538,7 @@ def concavity_FFS_down_to_top():
 	default_param = AGPD.ingest_param(default_param, sys.argv)
 
 
-	if(default_param["help"] or len(sys.argv)==1):
+	if(default_param["help"] or len(sys.argv)==1 or "help" in sys.argv):
 		print("""
 			This command-line tool run concavity analysis tools from LSDTopoTools.
 			Description of the algorithms in Mudd et al., 2018 -> https://www.earth-surf-dynam.net/6/505/2018/
@@ -651,7 +654,7 @@ def concavity_from_csv():
 	# default_param = AGPD.ingest_param(default_param, sys.argv)
 
 
-	# if(default_param["help"] or len(sys.argv)==1):
+	# if(default_param["help"] or len(sys.argv)==1 or "help" in sys.argv):
 	# 	print("""
 	# 		This command-line tool run concavity analysis tools from LSDTopoTools.
 	# 		Description of the algorithms in Mudd et al., 2018 -> https://www.earth-surf-dynam.net/6/505/2018/
